@@ -6,6 +6,11 @@
  *
  */
 #include "longpress.h"
+#include <list>
+#include <string>
+#include <unordered_map>
+#include <utility>
+#include <vector>
 
 namespace fcitx {
 
@@ -132,7 +137,7 @@ void setupDefaultLongPressConfig(LongPressConfig &config) {
             {"$", {"¢", "€", "£", "¥", "₹", "₽", "₺", "₩", "₱", "₿"}},
         };
     {
-        auto value = config.entries.mutableValue();
+        auto *value = config.entries.mutableValue();
         for (const auto &[key, candidates] : data) {
             LongPressEntryConfig entry;
             entry.key.setValue(key);
