@@ -8,52 +8,85 @@
 #include "library.h"
 #include <dlfcn.h>
 #include <fcntl.h>
-#include <sys/mman.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <cerrno>
 #include <cstdlib>
 #include <cstring>
+#include <filesystem>
 #include <functional>
 #include <memory>
 #include <string>
 #include <utility>
 #include "config.h"
+#include "flags.h"
 #include "macros.h"
 #include "misc.h"
+#include "standardpaths.h"
 #include "stringutils.h"
+#include "unixfd.h"
+
+#ifdef HAVE_SYS_MMAN_H
+#include <sys/mman.h>
+#endif
 
 namespace fcitx {
 
+namespace {
+
+#ifdef RTLD_NODELETE
+constexpr bool hasRTLDNoDelete = true;
+#else
+constexpr bool hasRTLDNoDelete = false;
+#endif
+
+} // namespace
+
 class LibraryPrivate {
 public:
-    LibraryPrivate(std::string path) : path_(std::move(path)) {}
+    LibraryPrivate(std::filesystem::path path)
+        : path_(std::move(path)), pathStr_(path_.string()) {}
     ~LibraryPrivate() { unload(); }
 
     bool unload() {
         if (!handle_) {
             return false;
         }
-        if (dlclose(handle_)) {
-            error_ = dlerror();
-            return false;
+
+        // If there is no RTLD_NODELETE and we don't want to unload, we leak
+        // it on purpose.
+        if (hasRTLDNoDelete ||
+            !loadFlag_.test(LibraryLoadHint::PreventUnloadHint)) {
+            if (dlclose(handle_)) {
+                error_ = dlerror();
+                return false;
+            }
         }
 
         handle_ = nullptr;
         return true;
     }
-
-    std::string path_;
+    const std::filesystem::path path_;
+    const std::string pathStr_;
     void *handle_ = nullptr;
     std::string error_;
+    Flags<fcitx::LibraryLoadHint> loadFlag_;
 };
 
 Library::Library(const std::string &path)
+    : Library(std::filesystem::path(path)) {}
+
+Library::Library(const char *path) : Library(std::filesystem::path(path)) {}
+
+Library::Library(const std::filesystem::path &path)
     : d_ptr(std::make_unique<LibraryPrivate>(path)) {}
 
 FCITX_DEFINE_DEFAULT_DTOR_AND_MOVE(Library)
 
 bool Library::load(Flags<fcitx::LibraryLoadHint> hint) {
+    if (loaded()) {
+        return true;
+    }
     FCITX_D();
     int flag = 0;
     if (hint & LibraryLoadHint::ResolveAllSymbolsHint) {
@@ -62,9 +95,11 @@ bool Library::load(Flags<fcitx::LibraryLoadHint> hint) {
         flag |= RTLD_LAZY;
     }
 
+#ifdef RTLD_NODELETE
     if (hint & LibraryLoadHint::PreventUnloadHint) {
         flag |= RTLD_NODELETE;
     }
+#endif
 
     if (hint & LibraryLoadHint::ExportExternalSymbolsHint) {
         flag |= RTLD_GLOBAL;
@@ -74,18 +109,21 @@ bool Library::load(Flags<fcitx::LibraryLoadHint> hint) {
     if (hint & LibraryLoadHint::NewNameSpace) {
         // allow dlopen self
         d->handle_ = dlmopen(
-            LM_ID_NEWLM, !d->path_.empty() ? d->path_.c_str() : nullptr, flag);
+            LM_ID_NEWLM,
+            !d->path_.empty() ? d->path_.string().c_str() : nullptr, flag);
     } else
 #endif
     {
-        d->handle_ =
-            dlopen(!d->path_.empty() ? d->path_.c_str() : nullptr, flag);
+        d->handle_ = dlopen(
+            !d->path_.empty() ? d->path_.string().c_str() : nullptr, flag);
     }
     if (!d->handle_) {
         d->error_ = dlerror();
         return false;
     }
 
+    d->loadFlag_ = hint;
+
     return true;
 }
 
@@ -126,8 +164,8 @@ bool Library::findData(const char *slug, const char *magic, size_t lenOfMagic,
         return true;
     }
 
-    int fd = open(d->path_.c_str(), O_RDONLY);
-    if (fd < 0) {
+    UnixFD fd = StandardPaths::openPath(d->path_);
+    if (!fd.isValid()) {
         d->error_ = strerror(errno);
         return false;
     }
@@ -136,21 +174,25 @@ bool Library::findData(const char *slug, const char *magic, size_t lenOfMagic,
     bool result = false;
     do {
         struct stat statbuf;
-        int statresult = fstat(fd, &statbuf);
+        int statresult = fstat(fd.fd(), &statbuf);
         if (statresult < 0) {
             d->error_ = strerror(errno);
             break;
         }
+        void *data = nullptr;
+#ifdef HAVE_SYS_MMAN_H
+        data =
+            mmap(nullptr, statbuf.st_size, PROT_READ, MAP_PRIVATE, fd.fd(), 0);
         void *needunmap = nullptr;
-        void *data = needunmap =
-            mmap(nullptr, statbuf.st_size, PROT_READ, MAP_PRIVATE, fd, 0);
+        needunmap = data;
+#endif
         if (!data) {
             data = malloc(statbuf.st_size);
             needfree.reset(data);
             if (!data) {
                 break;
             }
-            if (read(fd, data, statbuf.st_size) != statbuf.st_size) {
+            if (read(fd.fd(), data, statbuf.st_size) != statbuf.st_size) {
                 break;
             }
         }
@@ -163,13 +205,13 @@ bool Library::findData(const char *slug, const char *magic, size_t lenOfMagic,
             parser(pos);
         }
         result = true;
+#ifdef HAVE_SYS_MMAN_H
         if (needunmap) {
             munmap(needunmap, statbuf.st_size);
         }
+#endif
     } while (false);
 
-    close(fd);
-
     return result;
 }
 
@@ -188,7 +230,11 @@ bool Library::isNewNamespaceSupported() {
 
 const std::string &Library::path() const {
     FCITX_D();
-    return d->path_;
+    return d->pathStr_;
 }
 
+const std::filesystem::path &Library::fspath() const {
+    FCITX_D();
+    return d->path_;
+}
 } // namespace fcitx
