@@ -7,6 +7,7 @@
 #ifndef _FCITX_UTILS_TESTING_H_
 #define _FCITX_UTILS_TESTING_H_
 
+#include <filesystem>
 #include <string>
 #include <vector>
 #include <fcitx-utils/fcitxutils_export.h>
@@ -55,6 +56,11 @@ setupTestingEnvironment(const std::string &testBinaryDir,
                         const std::vector<std::string> &addonDirs,
                         const std::vector<std::string> &dataDirs);
 
+FCITXUTILS_EXPORT void
+setupTestingEnvironmentPath(const std::filesystem::path &testBinaryDir,
+                            const std::vector<std::filesystem::path> &addonDirs,
+                            const std::vector<std::filesystem::path> &dataDirs);
+
 } // namespace fcitx
 
 #endif // _FCITX_UTILS_TESTING_H_
