@@ -1,15 +1,19 @@
-#ifndef WL_DATA_SOURCE
-#define WL_DATA_SOURCE
+#ifndef WL_DATA_SOURCE_H_
+#define WL_DATA_SOURCE_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
 namespace fcitx::wayland {
+
 class WlDataSource final {
 public:
     static constexpr const char *interface = "wl_data_source";
     static constexpr const wl_interface *const wlInterface =
         &wl_data_source_interface;
     static constexpr const uint32_t version = 3;
-    typedef wl_data_source wlType;
+    using wlType = wl_data_source;
     operator wl_data_source *() { return data_.get(); }
     WlDataSource(wlType *data);
     WlDataSource(WlDataSource &&other) noexcept = delete;
@@ -19,6 +23,7 @@ public:
     void setUserData(void *userData) { userData_ = userData; }
     void offer(const char *mimeType);
     void setActions(uint32_t dndActions);
+
     auto &target() { return targetSignal_; }
     auto &send() { return sendSignal_; }
     auto &cancelled() { return cancelledSignal_; }
@@ -35,6 +40,7 @@ private:
     fcitx::Signal<void()> dndDropPerformedSignal_;
     fcitx::Signal<void()> dndFinishedSignal_;
     fcitx::Signal<void(uint32_t)> actionSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<wl_data_source, &destructor> data_;
@@ -42,5 +48,7 @@ private:
 static inline wl_data_source *rawPointer(WlDataSource *p) {
     return p ? static_cast<wl_data_source *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // WL_DATA_SOURCE_H_
