@@ -1,16 +1,21 @@
-#ifndef WL_POINTER
-#define WL_POINTER
+#ifndef WL_POINTER_H_
+#define WL_POINTER_H_
+#include <cstdint>
 #include <wayland-client.h>
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
 #include "fcitx-utils/signals.h"
 namespace fcitx::wayland {
+
 class WlSurface;
+
 class WlPointer final {
 public:
     static constexpr const char *interface = "wl_pointer";
     static constexpr const wl_interface *const wlInterface =
         &wl_pointer_interface;
-    static constexpr const uint32_t version = 7;
-    typedef wl_pointer wlType;
+    static constexpr const uint32_t version = 9;
+    using wlType = wl_pointer;
     operator wl_pointer *() { return data_.get(); }
     WlPointer(wlType *data);
     WlPointer(WlPointer &&other) noexcept = delete;
@@ -20,6 +25,7 @@ public:
     void setUserData(void *userData) { userData_ = userData; }
     void setCursor(uint32_t serial, WlSurface *surface, int32_t hotspotX,
                    int32_t hotspotY);
+
     auto &enter() { return enterSignal_; }
     auto &leave() { return leaveSignal_; }
     auto &motion() { return motionSignal_; }
@@ -29,6 +35,8 @@ public:
     auto &axisSource() { return axisSourceSignal_; }
     auto &axisStop() { return axisStopSignal_; }
     auto &axisDiscrete() { return axisDiscreteSignal_; }
+    auto &axisValue120() { return axisValue120Signal_; }
+    auto &axisRelativeDirection() { return axisRelativeDirectionSignal_; }
 
 private:
     static void destructor(wl_pointer *);
@@ -43,6 +51,9 @@ private:
     fcitx::Signal<void(uint32_t)> axisSourceSignal_;
     fcitx::Signal<void(uint32_t, uint32_t)> axisStopSignal_;
     fcitx::Signal<void(uint32_t, int32_t)> axisDiscreteSignal_;
+    fcitx::Signal<void(uint32_t, int32_t)> axisValue120Signal_;
+    fcitx::Signal<void(uint32_t, uint32_t)> axisRelativeDirectionSignal_;
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<wl_pointer, &destructor> data_;
@@ -50,5 +61,7 @@ private:
 static inline wl_pointer *rawPointer(WlPointer *p) {
     return p ? static_cast<wl_pointer *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // WL_POINTER_H_
