@@ -1,19 +1,23 @@
-#ifndef WP_CURSOR_SHAPE_MANAGER_V1
-#define WP_CURSOR_SHAPE_MANAGER_V1
+#ifndef WP_CURSOR_SHAPE_MANAGER_V1_H_
+#define WP_CURSOR_SHAPE_MANAGER_V1_H_
+#include <cstdint>
 #include <wayland-client.h>
-#include "fcitx-utils/signals.h"
-#include "wayland-cursor-shape-client-protocol.h"
+#include <wayland-util.h>
+#include "fcitx-utils/misc.h"
+#include "wayland-cursor-shape-v1-client-protocol.h" // IWYU pragma: export
 namespace fcitx::wayland {
+
 class WlPointer;
 class WpCursorShapeDeviceV1;
 class ZwpTabletToolV2;
+
 class WpCursorShapeManagerV1 final {
 public:
     static constexpr const char *interface = "wp_cursor_shape_manager_v1";
     static constexpr const wl_interface *const wlInterface =
         &wp_cursor_shape_manager_v1_interface;
     static constexpr const uint32_t version = 1;
-    typedef wp_cursor_shape_manager_v1 wlType;
+    using wlType = wp_cursor_shape_manager_v1;
     operator wp_cursor_shape_manager_v1 *() { return data_.get(); }
     WpCursorShapeManagerV1(wlType *data);
     WpCursorShapeManagerV1(WpCursorShapeManagerV1 &&other) noexcept = delete;
@@ -27,6 +31,7 @@ public:
 
 private:
     static void destructor(wp_cursor_shape_manager_v1 *);
+
     uint32_t version_;
     void *userData_ = nullptr;
     UniqueCPtr<wp_cursor_shape_manager_v1, &destructor> data_;
@@ -35,5 +40,7 @@ static inline wp_cursor_shape_manager_v1 *
 rawPointer(WpCursorShapeManagerV1 *p) {
     return p ? static_cast<wp_cursor_shape_manager_v1 *>(*p) : nullptr;
 }
+
 } // namespace fcitx::wayland
-#endif
+
+#endif // WP_CURSOR_SHAPE_MANAGER_V1_H_
