@@ -8,20 +8,20 @@
 #define _FCITX_INSTANCE_H_
 
 #include <memory>
+#include <string>
 #include <fcitx-utils/connectableobject.h>
-#include <fcitx-utils/handlertable.h>
+#include <fcitx-utils/eventdispatcher.h>
 #include <fcitx-utils/macros.h>
 #include <fcitx/event.h>
+#include <fcitx/fcitxcore_export.h>
 #include <fcitx/globalconfig.h>
 #include <fcitx/text.h>
-#include "fcitxcore_export.h"
 
 #define FCITX_INVALID_COMPOSE_RESULT 0xffffffff
 
 namespace fcitx {
 
 class InputContext;
-class KeyEvent;
 class InstancePrivate;
 class EventLoop;
 class AddonManager;
@@ -33,7 +33,7 @@ class UserInterfaceManager;
 class GlobalConfig;
 class FocusGroup;
 
-typedef std::function<void(Event &event)> EventHandler;
+using EventHandler = std::function<void(Event &event)>;
 
 /**
  * The function mode of virtual keyboard.
@@ -156,6 +156,15 @@ public:
     /// Get the fcitx event loop.
     EventLoop &eventLoop();
 
+    /**
+     * Return a shared event dispatcher that is already attached to instance's
+     * event loop.
+     *
+     * @return shared event dispatcher.
+     * @since 5.1.9
+     */
+    EventDispatcher &eventDispatcher();
+
     /// Get the addon manager.
     AddonManager &addonManager();
 
@@ -323,6 +332,9 @@ public:
     /// Exit the fcitx event loop
     void exit();
 
+    /// Exit the fcitx event loop with an exit code.
+    void exit(int exitCode);
+
     /// Restart fcitx instance, this should only be used within a regular Fcitx
     /// server, not within embedded mode.
     void restart();
@@ -430,13 +442,34 @@ public:
      * Show a small popup with input popup window with current input method
      * information.
      *
+     * The popup will be hidden after certain amount of time.
+     *
      * This is useful for input method that has multiple sub modes. It can be
      * called with switching sub modes within the input method.
      *
+     * The behavior is controlled by global config.
+     *
      * @param ic input context.
      */
     void showInputMethodInformation(InputContext *ic);
 
+    /**
+     * Show a small popup with input popup window with current input method
+     * information.
+     *
+     * The popup will be hidden after certain amount of time. The popup will
+     * always be displayed, regardless of the showInputMethodInformation in
+     * global config.
+     *
+     * This is useful for input method that has internal switches.
+     *
+     * @param ic input context.
+     * @param message message string to be displayed
+     * @since 5.1.11
+     */
+    void showCustomInputMethodInformation(InputContext *ic,
+                                          const std::string &message);
+
     /**
      * Check if need to invoke Instance::refresh.
      *
@@ -516,6 +549,28 @@ public:
 
     void setVirtualKeyboardFunctionMode(VirtualKeyboardFunctionMode mode);
 
+    /**
+     * Set if this instance is running as fcitx5 binary.
+     *
+     * This will affect return value of Instance::canRestart.
+     *
+     * @see Instance::canRestart
+     * @since 5.1.6
+     */
+    void setBinaryMode();
+
+    /**
+     * Check if fcitx 5 can safely restart by itself.
+     *
+     * When the existing fcitx 5 instance returns false, fcitx5 -r, or
+     * Instance::restart will just be no-op.
+     *
+     * @return whether it is safe for fcitx to restart on its own.
+     * @see AddonInstance::setCanRestart
+     * @since 5.1.6
+     */
+    bool canRestart() const;
+
 protected:
     // For testing purpose
     InstancePrivate *privateData();
