@@ -7,20 +7,27 @@
 #ifndef _FCITX_MODULES_NOTIFICATIONS_NOTIFICATIONS_H_
 #define _FCITX_MODULES_NOTIFICATIONS_NOTIFICATIONS_H_
 
-#include <functional>
+#include <chrono>
+#include <cstdint>
+#include <memory>
+#include <string>
+#include <unordered_map>
 #include <unordered_set>
 #include <utility>
+#include <vector>
 #include "fcitx-config/configuration.h"
 #include "fcitx-config/iniparser.h"
+#include "fcitx-config/option.h"
+#include "fcitx-config/rawconfig.h"
 #include "fcitx-utils/dbus/bus.h"
 #include "fcitx-utils/dbus/servicewatcher.h"
-#include "fcitx-utils/fs.h"
+#include "fcitx-utils/flags.h"
 #include "fcitx-utils/i18n.h"
 #include "fcitx/addoninstance.h"
 #include "fcitx/instance.h"
 #include "notifications_public.h"
 
-namespace fcitx {
+namespace fcitx::notifications {
 
 FCITX_CONFIGURATION(NotificationsConfig,
                     fcitx::Option<std::vector<std::string>> hiddenNotifications{
@@ -57,6 +64,13 @@ public:
 
     void updateConfig();
 
+    uint32_t sendNotificationInternal(
+        const std::string &appName, uint32_t replaceId,
+        const std::string &appIcon, const std::string &summary,
+        const std::string &body, const std::vector<std::string> &actions,
+        int32_t timeout, NotificationActionCallback actionCallback,
+        NotificationClosedCallback closedCallback, bool transient);
+
     uint32_t sendNotification(const std::string &appName, uint32_t replaceId,
                               const std::string &appIcon,
                               const std::string &summary,
@@ -109,12 +123,14 @@ private:
     std::unique_ptr<dbus::ServiceWatcherEntry> watcherEntry_;
 
     int lastTipId_ = 0;
+    std::chrono::time_point<std::chrono::steady_clock> lastTipTimestamp_;
     uint64_t internalId_ = 0;
     uint64_t epoch_ = 0;
 
     std::unordered_map<uint64_t, NotificationItem> items_;
     std::unordered_map<uint32_t, uint64_t> globalToInternalId_;
 };
-} // namespace fcitx
+
+} // namespace fcitx::notifications
 
 #endif // _FCITX_MODULES_NOTIFICATIONS_NOTIFICATIONS_H_
