@@ -9,6 +9,7 @@
 #include <fcntl.h>
 #include <cstddef>
 #include <cstdint>
+#include <filesystem>
 #include <functional>
 #include <map>
 #include <memory>
@@ -17,10 +18,10 @@
 #include <stdexcept>
 #include <string>
 #include <string_view>
+#include <system_error>
 #include <utility>
 #include <vector>
 #include <cairo.h>
-#include <xcb/xcb.h>
 #include "fcitx-config/iniparser.h"
 #include "fcitx-config/rawconfig.h"
 #include "fcitx-utils/color.h"
@@ -31,7 +32,7 @@
 #include "fcitx-utils/log.h"
 #include "fcitx-utils/misc.h"
 #include "fcitx-utils/misc_p.h"
-#include "fcitx-utils/standardpath.h"
+#include "fcitx-utils/standardpaths.h"
 #include "fcitx-utils/stringutils.h"
 #include "fcitx/addonfactory.h"
 #include "fcitx/addoninstance.h"
@@ -45,6 +46,7 @@
 #include "plasmathemewatchdog.h"
 #include "theme.h"
 #ifdef ENABLE_X11
+#include <xcb/xcb.h>
 #include "xcb_public.h"
 #include "xcbui.h"
 #endif
@@ -263,20 +265,17 @@ void ClassicUI::suspend() {
 }
 
 const Configuration *ClassicUI::getConfig() const {
-    std::set<std::string> themeDirs;
-    StandardPath::global().scanFiles(
-        StandardPath::Type::PkgData, "themes",
-        [&themeDirs](const std::string &path, const std::string &dir, bool) {
-            if (fs::isdir(stringutils::joinPath(dir, path))) {
-                themeDirs.insert(path);
-            }
-            return true;
+    auto themeDirs = StandardPaths::global().locate(
+        StandardPathsType::PkgData, "themes",
+        [](const std::filesystem::path &path) {
+            std::error_code ec;
+            return std::filesystem::is_directory(path, ec);
         });
     std::map<std::string, std::string, std::less<>> themes;
-    for (const auto &themeName : themeDirs) {
-        auto file = StandardPath::global().open(
-            StandardPath::Type::PkgData,
-            stringutils::joinPath("themes", themeName, "theme.conf"), O_RDONLY);
+    for (const auto &[themeName, _] : themeDirs) {
+        auto file = StandardPaths::global().open(
+            StandardPathsType::PkgData,
+            std::filesystem::path("themes") / themeName / "theme.conf");
         if (file.fd() < 0) {
             continue;
         }
@@ -507,8 +506,8 @@ void ClassicUI::setSubConfig(const std::string &path,
         getSubConfig(path);
     }
     theme.load(name, config);
-    safeSaveAsIni(theme, StandardPath::Type::PkgData,
-                  stringutils::joinPath("themes", name, "theme.conf"));
+    safeSaveAsIni(theme, StandardPathsType::PkgData,
+                  std::filesystem::path("themes") / name / "theme.conf");
 }
 
 std::vector<unsigned char> ClassicUI::labelIcon(const std::string &label,
