@@ -7,17 +7,14 @@
 #ifndef _FCITX_UI_CLASSIC_WAYLANDCURSORTHEME_H_
 #define _FCITX_UI_CLASSIC_WAYLANDCURSORTHEME_H_
 
-#include <cstdint>
 #include <memory>
+#include <string>
 #include <unordered_map>
 #include <wayland-cursor.h>
-#include "fcitx-utils/misc.h"
+#include "fcitx-utils/signals.h"
 #include "config.h"
-#include "display.h"
 #include "portalsettingmonitor.h"
-#include "wl_compositor.h"
 #include "wl_shm.h"
-#include "wl_surface.h"
 
 namespace fcitx::classicui {
 class WaylandUI;
@@ -34,7 +31,7 @@ public:
 
     auto &themeChanged() const { return themeChangedSignal_; }
 
-    WaylandCursorInfo loadCursorTheme(int size);
+    WaylandCursorInfo loadCursorTheme(int scale);
     auto cursorSize() const { return cursorSize_; }
 
 private:
