@@ -81,9 +81,7 @@ constexpr char testCompose[] = {
     "BELOW\n"};
 
 int main() {
-    setupTestingEnvironment(FCITX5_BINARY_DIR,
-                            {"testing/testfrontend", "testing/testui"},
-                            {"test"});
+    setupTestingEnvironmentPath(FCITX5_BINARY_DIR, {"bin"}, {"test"});
 
     char arg0[] = "testcompose";
     char arg1[] = "--disable=all";
