@@ -4,9 +4,9 @@
  * SPDX-License-Identifier: LGPL-2.1-or-later
  *
  */
-#include <fcitx-utils/log.h>
-#include <fcitx-utils/textformatflags.h>
-#include <fcitx/text.h>
+#include "fcitx-utils/log.h"
+#include "fcitx-utils/textformatflags.h"
+#include "fcitx/text.h"
 using namespace fcitx;
 
 void test_basic() {
